==> ace_5.7.7.orig.tar.gz: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_component.h <==
/* -*- c++ -*- */

//=============================================================================
/**
 *  @file    be_visitor_component.h
 *
 *  $Id: be_visitor_component.h 89018 2010-02-15 22:36:07Z parsons $
 *
 *  Concrete visitors for the Component class
 *
 *
 *  @author Jeff Parsons
 */
//=============================================================================


#ifndef TAO_BE_VISITOR_COMPONENT_H
#define TAO_BE_VISITOR_COMPONENT_H

#include "be_visitor_interface.h"
#include "be_visitor_component_scope.h"

#include "be_visitor_component/component.h"
#include "be_visitor_component/component_ch.h"
#include "be_visitor_component/component_ci.h"
#include "be_visitor_component/component_cs.h"
#include "be_visitor_component/component_sh.h"
#include "be_visitor_component/component_si.h"
#include "be_visitor_component/component_ss.h"
#include "be_visitor_component/component_svh.h"
#include "be_visitor_component/facet_svh.h"
#include "be_visitor_component/context_svh.h"
#include "be_visitor_component/servant_svh.h"
#include "be_visitor_component/component_svs.h"
#include "be_visitor_component/facet_svs.h"
#include "be_visitor_component/context_svs.h"
#include "be_visitor_component/servant_svs.h"
#include "be_visitor_component/component_ex_idl.h"
#include "be_visitor_component/facet_ex_idl.h"
#include "be_visitor_component/executor_ex_idl.h"
#include "be_visitor_component/context_ex_idl.h"
#include "be_visitor_component/component_exh.h"
#include "be_visitor_component/facet_exh.h"
#include "be_visitor_component/executor_exh.h"
#include "be_visitor_component/component_exs.h"
#include "be_visitor_component/facet_exs.h"
#include "be_visitor_component/executor_exs.h"
#include "be_visitor_component/any_op_ch.h"
#include "be_visitor_component/any_op_cs.h"
#include "be_visitor_component/cdr_op_ch.h"
#include "be_visitor_component/cdr_op_cs.h"

#endif /* TAO_BE_VISITOR_COMPONENT_H */

==> ace_6.0.1.orig.tar.gz: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_component.h <==
/* -*- c++ -*- */

//=============================================================================
/**
 *  @file    be_visitor_component.h
 *
 *  $Id: be_visitor_component.h 92767 2010-12-01 22:15:57Z parsons $
 *
 *  Concrete visitors for the Component class
 *
 *
 *  @author Jeff Parsons
 */
//=============================================================================

#ifndef TAO_BE_VISITOR_COMPONENT_H
#define TAO_BE_VISITOR_COMPONENT_H

#include "be_visitor_interface.h"
#include "be_visitor_component_scope.h"

#include "be_visitor_component/component.h"
#include "be_visitor_component/component_svh.h"
#include "be_visitor_component/facet_svh.h"
#include "be_visitor_component/context_svh.h"
#include "be_visitor_component/servant_svh.h"
#include "be_visitor_component/component_svs.h"
#include "be_visitor_component/facet_svs.h"
#include "be_visitor_component/context_svs.h"
#include "be_visitor_component/servant_svs.h"
#include "be_visitor_component/component_ex_idl.h"
#include "be_visitor_component/facet_ex_idl.h"
#include "be_visitor_component/executor_ex_idl.h"
#include "be_visitor_component/context_ex_idl.h"
#include "be_visitor_component/component_exh.h"
#include "be_visitor_component/facet_exh.h"
#include "be_visitor_component/executor_private_exh.h"
#include "be_visitor_component/executor_exh.h"
#include "be_visitor_component/component_exs.h"
#include "be_visitor_component/facet_exs.h"
#include "be_visitor_component/executor_exs.h"
#include "be_visitor_component/executor_exs_attr_init.h"
#include "be_visitor_component/component_ami_rh_ex_base.h"
#include "be_visitor_component/component_ami_rh_exh.h"
#include "be_visitor_component/component_ami_rh_exs.h"

#endif /* TAO_BE_VISITOR_COMPONENT_H */
